import { Request, Response, NextFunction } from 'express';
import jwt from 'jsonwebtoken';

export const authMiddleware = (req: Request, res: Response, next: NextFunction) => {
  try {
    const token = req.headers.authorization?.split(' ')[1];
    if (!token) {
      return res.status(401).json({ message: 'Токен не предоставлен' });
    }
    const secretKey: string = process.env.JWT_SECRET as string;
    const decoded = jwt.verify(token, secretKey);
    (req as any).user = decoded;
    next();
  } catch (error) {
    return res.status(401).json({ message: 'Недействительный токен' });
  }
};

export const roleMiddleware = (roles: string[]) => {
  return (req: Request, res: Response, next: NextFunction) => {
    try {
      const userRole = (req as any).user.role;
      if (!roles.includes(userRole)) {
        return res.status(403).json({ message: 'Доступ запрещен' });
      }
      next();
    } catch (error) {
      return res.status(403).json({ message: 'Доступ запрещен' });
    }
  };
}; 