import { Router } from 'express';
import { AdminController } from '../controllers/admin.controller';
import { authMiddleware, roleMiddleware } from '../middleware/auth.middleware';
import LocationController from '../controllers/location.controller';

const router = Router();

router.use(authMiddleware);
router.use(roleMiddleware(['admin']));

// Маршруты для управления пользователями
router.get('/users', AdminController.getUsers);
router.post('/users', AdminController.createUser);
router.put('/users/:id', AdminController.updateUser);
router.delete('/users/:id', AdminController.deleteUser);

// Маршруты для управления ролями
router.get('/roles', AdminController.getRoles);
router.post('/roles', AdminController.createRole);
router.put('/roles/:id', AdminController.updateRole);
router.delete('/roles/:id', AdminController.deleteRole);

// Маршруты для получения разрешений
router.get('/permissions', AdminController.getPermissions);

// Маршруты для управления локациями
router.get('/locations', LocationController.getAll);
router.post('/locations', LocationController.create);
router.put('/locations/:id', LocationController.update);
router.delete('/locations/:id', LocationController.delete);

// Маршруты для управления категориями
router.get('/categories', AdminController.getCategories);
router.post('/categories', AdminController.createCategory);
router.put('/categories/:id', AdminController.updateCategory);
router.delete('/categories/:id', AdminController.deleteCategory);

export default router; 